RawCc

Struct RawCc 

pub struct RawCc<T: ?Sized, O: AbstractObjectSpace>(/* private fields */);
Low-level type for Cc<T>.

Implementations

Source

impl<T: Trace> RawCc<T, ObjectSpace>

pub fn new(value: T) -> Cc<T>

Constructs a new Cc<T> in a thread-local storage.

To collect cycles, use collect_thread_cycles.

Source

impl<T: Trace, O: AbstractObjectSpace> RawCc<T, O>

pub fn into_dyn(self) -> RawCc<dyn Trace, O>

Convert to RawCc<dyn Trace>.

Source

impl<T: Trace + Clone> RawCc<T, ObjectSpace>

pub fn update_with(&mut self, update_func: impl FnMut(&mut T))

Update the value T in a copy-on-write way.

If the ref count is 1, the value is updated in-place. Otherwise a new Cc<T> will be created.

Source

impl<T: ?Sized, O: AbstractObjectSpace> RawCc<T, O>

pub fn trace(&self, tracer: &mut Tracer<'_>)

trace without T: Trace bound.

Useful for structures with Cc<T> fields where T does not implement Trace. For example, struct S(Cc<Box<dyn MyTrait>>). To implement Trace for S, it can use Cc::trace(&self.0, tracer).

Source

impl<T: ?Sized> RawCc<T, ThreadedObjectSpace>

pub fn borrow(&self) -> ThreadedCcRef<'_, T>

Immutably borrows the wrapped value.

The borrow lasts until the returned value exits scope.